pub async fn get_shipment_details(
configuration: &Configuration,
shipment_id: &str
) -> Result<GetShipmentDetailsResponse, Error>Expand description
Returns the shipment details required to issue an invoice for the specified shipment. Usage Plans: | Plan type | Rate (requests per second) | Burst | | –– | –– | –– | |Default| 1.133 | 25 | |Selling partner specific| Variable | Variable | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation. Rate limits for some selling partners will vary from the default rate and burst shown in the table above. For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.